diff sat/tools/async_trigger.py @ 4037:524856bd7b19

massive refactoring to switch from camelCase to snake_case: historically, Libervia (SàT before) was using camelCase as allowed by PEP8 when using a pre-PEP8 code, to use the same coding style as in Twisted. However, snake_case is more readable and it's better to follow PEP8 best practices, so it has been decided to move on full snake_case. Because Libervia has a huge codebase, this ended with a ugly mix of camelCase and snake_case. To fix that, this patch does a big refactoring by renaming every function and method (including bridge) that are not coming from Twisted or Wokkel, to use fully snake_case. This is a massive change, and may result in some bugs.
author Goffi <goffi@goffi.org>
date Sat, 08 Apr 2023 13:54:42 +0200
parents e14847bf65c0
children
line wrap: on
line diff
--- a/sat/tools/async_trigger.py	Fri Apr 07 15:18:39 2023 +0200
+++ b/sat/tools/async_trigger.py	Sat Apr 08 13:54:42 2023 +0200
@@ -25,10 +25,10 @@
 from twisted.internet import defer
 
 class TriggerManager(sync_trigger.TriggerManager):
     """This is a TriggerManager with an new asyncPoint method"""
 
     @defer.inlineCallbacks
-    def asyncPoint(self, point_name, *args, **kwargs):
+    def async_point(self, point_name, *args, **kwargs):
         """This put a trigger point with potentially async Deferred
 
         All the triggers for that point will be run
@@ -47,25 +47,25 @@
 
         for priority, trigger in self.__triggers[point_name]:
             try:
-                cont = yield utils.asDeferred(trigger, *args, **kwargs)
+                cont = yield utils.as_deferred(trigger, *args, **kwargs)
                 if can_cancel and not cont:
                     defer.returnValue(False)
             except sync_trigger.SkipOtherTriggers:
                 break
         defer.returnValue(True)
 
-    async def asyncReturnPoint(
+    async def async_return_point(
         self,
         point_name: str,
         *args, **kwargs
     ) -> Tuple[bool, Any]:
-        """Async version of returnPoint"""
+        """Async version of return_point"""
         if point_name not in self.__triggers:
             return True, None
 
         for priority, trigger in self.__triggers[point_name]:
             try:
-                cont, ret_value = await utils.asDeferred(trigger, *args, **kwargs)
+                cont, ret_value = await utils.as_deferred(trigger, *args, **kwargs)
                 if not cont:
                     return False, ret_value
             except sync_trigger.SkipOtherTriggers:
@@ -25,10 +25,10 @@
 
 class TriggerManager(sync_trigger.TriggerManager):
-    """This is a TriggerManager with an new asyncPoint method"""
+    """This is a TriggerManager with an new async_point method"""
 
     @defer.inlineCallbacks